@@ -101,6 +101,7 @@ animate_process <- function(eventlog,
   token_start <- token_end <- activity_duration <- token_duration <- NULL
   constraint <- weight <- NULL
 
+
   mode <- match.arg(mode)
   initial_state <- match.arg(initial_state)
 
@@ -394,5 +395,11 @@ transform_time <- function(data, cases, mode, a_factor, timeline_start, timeline
 
 # Utility functions
 # https://github.com/gertjanssenswillen/processmapR/blob/master/R/utils.R
+
 case_id_ <- function(eventlog) rlang::sym(bupaR::case_id(eventlog))
+activity_id_ <- function(eventlog) rlang::sym(bupaR::activity_id(eventlog))
+activity_instance_id_ <- function(eventlog) rlang::sym(bupaR::activity_instance_id(eventlog))
+resource_id_ <- function(eventlog) rlang::sym(bupaR::resource_id(eventlog))
 timestamp_ <- function(eventlog) rlang::sym(bupaR::timestamp(eventlog))
+lifecycle_id_ <- function(eventlog) rlang::sym(bupaR::lifecycle_id(eventlog))
+
